package us.blanshard.stubout;

/**
 * Implemented by all JUnit 3 TestCase subclasses that provide stubbing.
 * 
 * @author Luke Blanshard
 */
public interface ReloadableTest
{
    /**
     * Runs the named test case by setting this object's name and then calling
     * the superclass's runBare method. This method is called by the Stubber on
     * the version of the test object created from the reloaded test class.
     * 
     * @param name
     *            the name of the test method to run
     * @throws Throwable
     *             from the test
     */
    public void runBareTest( String name ) throws Throwable;

    /**
     * Returns the name of the test.
     */
    public String getName();

    /**
     * Called on the original test object before its class is reloaded and the
     * reloaded version is run. All
     * {@linkplain Stubber#replaceClass(Class,Class) class replacements} and
     * {@linkplain Stubber#exclude(Stubber.Exclusion) stubbing exclusions} must
     * be established within this method.
     */
    public void beforeReloading();
}
